<?php

namespace Drupal\commerce_pos_loyalty_points_support\Plugin\Field\FieldWidget;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldWidget\EntityReferenceAutocompleteWidget;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Entity\User;

/**
 * Plugin implementation of the 'entity_reference_autocomplete_tags' widget.
 *
 * @FieldWidget(
 *   id = "entity_reference_autocomplete_loyalty_points",
 *   label = @Translation("Autocomplete (show loyalty points)"),
 *   description = @Translation("An autocomplete text field that displays customer loyalty points."),
 *   field_types = {
 *     "entity_reference"
 *   }
 * )
 */
class EntityReferenceAutocompleteLoyaltyPointsWidget extends EntityReferenceAutocompleteWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);
    $referenced_entities = $items->referencedEntities();
    if (isset($referenced_entities[$delta])) {
      $uid = $referenced_entities[$delta]->id();
      $default_points = $this->getLoyaltyPoints($uid);
    }

    $loyalty_points['container'] = [
      '#type' => 'fieldset',
//      '#theme' => 'loyalty_points_widget',
      '#title' => t('Loyalty points'),
      '#collapsed' => FALSE,
      '#collapsible' => TRUE,
    ];
    $loyalty_points['container']['display_loyalty_points'] = [
      '#type' => 'item',
      '#title' => isset($default_points) ? $default_points : '',
      '#id' => 'customer-loyalty-points',
    ];
    $loyalty_points['container']['get_loyalty_points'] = [
      '#type' => 'submit',
      '#value' => t('Check points'),
      '#ajax' => [
        'callback' => [$this, 'displayLoyaltyPoints'],
        'progress' => [
          'type' => 'throbber',
          'message' => t('Looking up...'),
        ],
      ],
    ];
    return $element + $loyalty_points['container'];
  }

  /**
   * Display loyalty points of a customer.
   */
  public function displayLoyaltyPoints(array &$form, FormStateInterface $form_state) {
    $message = t('No loyalty points found.');
    if (isset($form_state->getValue('uid')[0]['target_id'])) {
      $uid = $form_state->getValue('uid')[0]['target_id'];
      if ($uid) {
        $message = $this->getLoyaltyPoints($uid);
      }
    }
    else {
      $message = t('User not found');
    }

    // Return ajax response.
    $ajax_response = new AjaxResponse();
    return $ajax_response->addCommand(new HtmlCommand('#customer-loyalty-points', $message));
  }

  /**
   * Fetch loyalty points of a customer.
   */
  protected function getLoyaltyPoints($uid) {
    $user = User::load($uid);
    /** @var \Drupal\commerce_loyalty_points\LoyaltyPointsStorageInterface $loyalty_points_storage */
    $loyalty_points_storage = \Drupal::entityTypeManager()->getStorage('commerce_loyalty_points');
    $points = $loyalty_points_storage->loadAndAggregateUserLoyaltyPoints($uid);
    $message['#markup'] = '<strong>' . t('Points for @user: @points', [
      '@user' => $user->getUsername(),
      '@points' => $points,
    ]) . '</strong>';

    return \Drupal::service('renderer')->render($message);
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    return $values;
  }

}
