<?php

namespace Drupal\commerce_loyalty_points\Entity;

use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;

/**
 * Defines the LoyaltyPoints entity.
 *
 * @ContentEntityType(
 *   id = "commerce_loyalty_points",
 *   label = @Translation("Loyalty points"),
 *   label_singular = @Translation("Loyalty point"),
 *   label_plural = @Translation("Loyalty points"),
 *   label_count = @PluralTranslation(
 *     singular = "@count loyalty point",
 *     plural = "@count loyalty points",
 *   ),
 *   handlers = {
 *     "storage" = "Drupal\commerce_loyalty_points\LoyaltyPointsStorage",
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *     "form" = {
 *       "add" = "Drupal\Core\Entity\ContentEntityForm",
 *       "edit" = "Drupal\Core\Entity\ContentEntityForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityDeleteForm"
 *     },
 *   },
 *   base_table = "commerce_loyalty_points",
 *   admin_permission = "administer loyalty points entities",
 *   entity_keys = {
 *     "id" = "lpid",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "collection" = "/admin/commerce/loyalty-points"
 *   },
 * )
 */
class LoyaltyPoints extends ContentEntityBase {

  /**
   * {@inheritdoc}
   */
  public function getLoyaltyPoints() {
    return $this->get('id')->value;
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['lpid']->setLabel(t('Loyalty point ID'))
      ->setDescription(t('The loyalty point identifier.'));

    $fields['uid'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('UID'))
      ->setDescription(t('User ID referenced from {users}.'))
      ->setSetting('target_type', 'user')
      ->setReadOnly(TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['loyalty_points'] = BaseFieldDefinition::create('decimal')
      ->setLabel(t('Loyalty points'))
      ->setReadOnly(TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['reason'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Reason'))
      ->setDescription(t('Reason for loyalty points given to a user.'))
      ->setSettings([
        'max_length' => 256,
        'text_processing' => 0,
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'string',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -4,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    return $fields;
  }

}
