<?php

namespace Drupal\commerce_loyalty_points;

use Drupal\commerce\CommerceContentEntityStorage;

/**
 * Defines the loyalty points storage.
 */
class LoyaltyPointsStorage extends CommerceContentEntityStorage implements LoyaltyPointsStorageInterface {

  /**
   * {@inheritdoc}
   */
  public function loadAndAggregateUserLoyaltyPoints($uid) {
    $total_loyalty_points = 0;
    $all_loyalty_points = $this->database->query(
      'SELECT loyalty_points FROM {commerce_loyalty_points} WHERE uid=:uid',
      [':uid' => $uid]
    )->fetchCol();

    foreach ($all_loyalty_points as $loyalty_point) {
      $total_loyalty_points += $loyalty_point;
    }

    return $total_loyalty_points;
  }

  /**
   * {@inheritdoc}
   */
  public function isEligibleCustomer($uid, $interval) {
    $last_negative_point_on = $this->database->query(
      'SELECT created FROM {commerce_loyalty_points} WHERE uid=:uid AND loyalty_points < 0 ORDER BY created DESC LIMIT 1',
      [':uid' => $uid]
    )->fetchCol();

    if (count($last_negative_point_on) > 0) {
      $timezone = drupal_get_user_timezone();
      $timezone_object = new \DateTimeZone($timezone);

      $now = new \DateTime();
      $now->setTimezone($timezone_object);

      $last_negative_point_on = new \DateTime('@' . $last_negative_point_on[0]);
      $last_negative_point_on->setTimezone($timezone_object);

      // Get the difference in weeks as it is the smallest unit of measure we have.
      $days = $now->diff($last_negative_point_on)->days;
      $weeks = $days / 7;

      switch ($interval) {
        case 'week':
          return $weeks > 1;

        break;
        case 'month':
          return $weeks > 4;

        break;
        case 'quarter':
          return $weeks > 12;

        break;
        case 'six_months':
          return $weeks > 24;

        break;
        case 'year':
          return $weeks > 52;

        break;
        case 'no_restriction':
          return TRUE;

        break;
      }
    }

    return TRUE;
  }

}
